--------------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.Std_Logic_1164.all;
USE IEEE.Std_Logic_Unsigned.all;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
ENTITY Configurable_IC7 IS
  PORT(
      Q0   : OUT std_logic;
      Q1   : OUT std_logic;
      Q2   : OUT std_logic;
      Q3   : OUT std_logic;
      CLR  : IN  std_logic;
      CEO  : OUT std_logic;
      TC   : OUT std_logic;
      CE   : IN  std_logic;
      C    : IN  std_logic
  );
END Configurable_IC7;
--------------------------------------------------------------------------------

--------------------------------------------------------------------------------
ARCHITECTURE structure OF Configurable_IC7 IS
--------------------------------------------------------------------------------
CONSTANT cMaxValue : std_logic_vector(3 downto 0) := "1111";
CONSTANT cMinValue : std_logic_vector(3 downto 0) := (OTHERS => '0');
SIGNAL Y : std_logic_vector(3 downto 0) := cMinValue;
SIGNAL TC_int: std_logic;
--------------------------------------------------------------------------------
BEGIN
    PROCESS(C, CLR)
    BEGIN
        IF CLR = '1' THEN
            Y <= cMinValue;
        ELSIF C'Event and C = '1' THEN
            IF (CE = '1') THEN
                IF Y >= cMaxValue THEN
                    Y <= cMinValue;
                ELSE
                    Y <= Y + 1;
                END IF;
            END IF;
        END IF;
    END PROCESS;
    TC_int <= '1' WHEN (Y = cMaxValue) ELSE
              '0';
    Q0 <= Y(0);
    Q1 <= Y(1);
    Q2 <= Y(2);
    Q3 <= Y(3);
    TC <= TC_int;
    CEO <= TC_int AND CE;
END structure;
--------------------------------------------------------------------------------
